 /*
 * file      : utils.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <string.h>

#include "libbasebuild.h"


OPTIONS_COMMAND_LINE OptionsCommandLine = {
	FALSE		// gboolean	BoolVerboseMode
};

// TRUE SI LE FICHIER EXISTE SINON FALSE
//
gboolean libutils_test_file_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISREG (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_REGULAR));
}
// TRUE SI LE DOSSIER EXISTE SINON FALSE
//
gboolean libutils_test_dir_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISDIR (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_DIR));
}
// AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
// 
void libutils_set_default_icone_to_win (GtkWidget *win)
{
	gchar     *LineCommand = NULL;
	GError    *error = NULL;

	LineCommand = g_strdup_printf ("%s/pixmaps/basebuild.png", PACKAGE_DATA_DIR);
	if (TRUE == libutils_test_file_exist (LineCommand)) {
		// LineCommand = g_strdup ("/home/cat/Projects/basebuild-0.0.4/pixmaps/basebuild.png");
	 	gtk_window_set_icon_from_file (GTK_WINDOW(win), LineCommand, &error);
	 	if (error) {
	 		GDK_PIXBUF_ERROR;
			g_critical ("Could not load pixbuf: %s\n", error->message);
			g_error_free (error);
		}
	}
	g_free (LineCommand);
	LineCommand = NULL;
}
// Execute WHICH Name_Prg et si 'gchar **Pathname_Prg' est non null retourne le resultat
// 
/*
gboolean libutils_find_file (gchar *p_find_file)
{
	gchar      *PathName = NULL;
	gboolean    BoolFind = FALSE;
	
	if (NULL == p_find_file) return (FALSE);
	if ('\0' == *p_find_file) return (FALSE);
	
	PathName = g_strdup_printf ("/usr/bin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	PathName = g_strdup_printf ("/usr/sbin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	PathName = g_strdup_printf ("/usr/local/bin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	return (FALSE);
}
*/
gboolean libutils_find_file (gchar *p_find_file)
{
	gchar      *PathName = NULL;
	
	if( NULL != p_find_file ) {
		if( NULL != (PathName = g_find_program_in_path( p_find_file ))) {
			g_free( PathName );	PathName = NULL;
			return( TRUE );
		}
	}
	
	return( FALSE );
}
// 
// 
size_t libutils_get_size_file (char *PathName)
{
	FILE   *fp;
	size_t  size = 0;

	if ((fp = fopen (PathName, "r"))) {
		fseek (fp, 0, SEEK_END);
		size = ftell (fp);
		fclose (fp);
	}
	return (size);
}
// 
// Algo retravaille depuis:
//	C EN ACTION - 2 ieme Edition - Yves Mettier
// 
gboolean libutils_copy_src_to_dest (gchar *filesrc, gchar *filedest)
{
	FILE	*fn = NULL;
	FILE	*fe = NULL;
	gchar	buf [ BUFSIZ ];
	size_t	size = libutils_get_size_file (filesrc);
	gulong	blk;
	gulong	cpt;
	
	if (0 == size) {
		fprintf (stderr, "La taille de : %s est NULLE !!!\n", filesrc);
		return (FALSE);
	}
	if (NULL == (fe = fopen (filesrc, "r"))) {
		fprintf (stderr, "Echec ouverture en lecture de: %s\n", filesrc);
		return (FALSE);
	}
	if (NULL == (fn = fopen (filedest, "w"))) {
		fprintf (stderr, "Echec ouverture en ecriture de: %s\n", filedest);
		fclose (fe);
		return (FALSE);
	}
	
	blk = size / BUFSIZ;
	
	g_print ("\t%s\n\t%s\n", filesrc, filedest);
	cpt = 0;
	while ( ! feof (fe)) {
		size_t	l;
		
		l = fread (buf, sizeof (*buf), BUFSIZ, fe);
		if (ferror (fe)) {
			fprintf (stderr, "Erreur de lecture\n");
			fclose (fn);
			fclose (fe);
			return (FALSE);
		}
		fwrite (buf, sizeof (*buf), l, fn);
		if (ferror (fn)) {
			fprintf (stderr, "Erreur d'ecriture\n");
			fclose (fn);
			fclose (fe);
			return (FALSE);
		}
		
		cpt ++;
	}
	fclose (fn);
	fclose (fe);
	
	return (TRUE);
}
// 
// 
// 
gboolean libutils_test_write( gchar *path )
{
	gboolean  BoolWriteOk = FALSE;
	FILE     *fp = NULL;
	gchar    *str = NULL;
	
	if (path[ 0 ] == '/' && path[ 1 ] != '\0') {
		str = g_strdup_printf ("%s/basebuild_tst_write_dummy.txt", path);
		if (NULL != (fp = fopen (str, "w"))) {
			BoolWriteOk = TRUE;
			fclose (fp);
			g_unlink (str);
		}
		g_free (str);
		str = NULL;
	}
	
	// TODO: FENETRE D ALERTE POUR L UTILISATEUR
	/*
	if (BoolWriteOk == FALSE) {
		wininfo_create (
			_("Erreur choix lieu de stockage !"),
			_("   Le lieu de stockage temporaire doit pouvoir     "),
			  "\n",
			_("   etre accessible en ecriture."),
			  "\n\n",
			_("   Veuillez recommencer."),
			  "\n",
			  "");
	}
	*/
	return (BoolWriteOk);
}
// 
// 
// 
gchar *libutils_string_toupper( gchar *p_str )
{
	gchar	*Str = g_strdup( p_str );
	gchar	*Ptr = Str;
	
	while( Ptr && *Ptr ) {
		*Ptr = g_ascii_toupper( *Ptr );
		Ptr ++;
	}
	
	return( Str );
}




















