 /*
 * file      : build_write.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "../lib_basebuild/libbasebuild.h"

#include "win_vte.h"
#include "def_src.h"
#include "win_info.h"
#include "configuser.h"
#include "proto.h"
#include "build.h"
#include "conv.h"
#include "callbacks.h"
#include "global.h"



VAR_BUILD VarBuild;
extern VAR_PROTO VarProto;


// 
// GENERATION 'Path + Name' avec le contenu de 'buffer'
// 
void BuildWrite_file( gchar *Path, gchar *Name, gchar *Ext, gchar *buffer )
{
	gchar	*LineCommand = NULL;
	FILE	*fp = NULL;
	
	LineCommand = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( LineCommand, "w" ))) {
		if( NULL != buffer ) {
			// g_fprintf (fp, buffer);
			fprintf( fp, "%s", buffer );
		}
		fclose( fp );
	}
	if( NULL != LineCommand ) {
		g_free( LineCommand );
		LineCommand = NULL;
	}
}
// 
// MAKEFILE.AM
// 
void BuildWrite_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	GList		*List = NULL;
	VAR_BUILD_SRC	*VarBuildSrc = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "SUBDIRS = ");
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "po ");
		}
		if (TRUE == VarBuild.Bool_dossier_lib_statique) {
			fprintf( fp, "%s ", VarBuild.NameLib);
		}
		List = g_list_first (VarBuild.ListPathSrc);
		while (List) {
			if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
				fprintf( fp, "%s ", VarBuildSrc->Name);
			}
			List = g_list_next (List);
		}
		if (TRUE == VarBuild.Bool_dossier_manpage) {
			fprintf( fp, "man ");
		}
		if( TRUE == Config.BoolRadioButonGui ) {
			if (TRUE == VarBuild.Bool_dossier_pixmaps) {
				fprintf( fp, "pixmaps ");
			}
			if (TRUE == VarBuild.Bool_dossier_menu) {
				fprintf( fp, "menu ");
			}
			if (TRUE == VarBuild.Bool_dossier_mime) {
				fprintf( fp, "mime ");
			}
			if (TRUE == VarBuild.Bool_dossier_glade) {
				fprintf( fp, "glade ");
			}
		}
		fprintf( fp, "\nACLOCAL_AMFLAGS = -I m4\n");
		fprintf( fp, "EXTRA_DIST = ");
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "config.rpath m4/ChangeLog\n");
		}
		
		fclose( fp );
	}
	
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// LIB/MAKEFILE.AM
// 
void BuildWrite_lib_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# %s/Makefile.am with BaseBuild\n#\n", VarBuild.NameLib);
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		if (TRUE == VarBuild.Bool_lib_gtk) {
			fprintf( fp, "\nINCLUDES = \\\n");
			fprintf( fp, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
			fprintf( fp, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
			fprintf( fp, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarBuild.NameProject);
			fprintf( fp, "	@PACKAGE_CFLAGS@\n");
			fprintf( fp, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
			fprintf( fp, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
			fprintf( fp, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
			fprintf( fp, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarBuild.NameProject);
		}
		fprintf( fp, "\nnoinst_LIBRARIES=%s.a\n", VarBuild.NameLib);
		fprintf( fp, "\n%s_a_SOURCES=lib.c lib.h\n", VarBuild.NameLib);
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// LIB/LIB.C
// 
void BuildWrite_LIB_C_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "/*\n");	
		fprintf( fp, " *  %s/lib.c\n", VarBuild.NameLib);
		fprintf( fp, " */\n");
		fprintf( fp, "\n");
		fprintf( fp, "#include <stdio.h>\n");
		fprintf( fp, "\n");
		fprintf( fp, "void libH_print_mess (char *p_mess)\n");
		fprintf( fp, "{\n");
		fprintf( fp, "\tprintf(\"%%s\", p_mess);\n");
		fprintf( fp, "}\n");
		fprintf( fp, "\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// LIB/LIB.H
// 
void BuildWrite_LIB_H_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "/*\n");
		fprintf( fp, " *  %s/lib.h\n", VarBuild.NameLib);
		fprintf( fp, " */\n");
		fprintf( fp, "\n");
		fprintf( fp, "#ifndef __libH_h__\n");
		fprintf( fp, "#define __libH_h__ 1\n");
		fprintf( fp, "\n");
		fprintf( fp, "void libH_print_mess (char *p_mess);\n");
		fprintf( fp, "\n");
		fprintf( fp, "#endif\n");
		fprintf( fp, "\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// GLADE/MAKEFILE.AM
// 
void BuildWrite_glade_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# glade/Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		fprintf( fp, "EXTRA_DIST = %s.glade\n", VarBuild.NameProject);
		fprintf( fp, "gladedir = $(datadir)/%s/glade\n", VarBuild.NameProject);
		fprintf( fp, "glade_DATA = %s.glade\n", VarBuild.NameProject);
		fprintf( fp, "\nuninstall:\n");
		fprintf( fp, "\trm -rf \"$(DESTDIR)$(datadir)/%s/\";\n", VarBuild.NameProject);
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// GLADE/NOM_PROJET.glade
// 
void BuildWrite_GLADE_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	gchar *BufGlade = 
		"<?xml version=\"1.0\"?>\n"
		"<interface>\n"
		"  <requires lib=\"gtk+\" version=\"2.16\"/>\n"
		"  <!-- interface-naming-policy project-wide -->\n"
		"  <object class=\"GtkWindow\" id=\"window_main\">\n"
		"    <property name=\"width_request\">300</property>\n"
		"    <property name=\"height_request\">100</property>\n"
		"    <property name=\"window_position\">center</property>\n"
		"    <signal name=\"destroy_event\" handler=\"on_window_main_destroy_event\"/>\n"
		"    <signal name=\"delete_event\" handler=\"on_window_main_delete_event\"/>\n"
		"    <signal name=\"key_press_event\" handler=\"on_window_main_key_press_event\"/>\n"
		"    <signal name=\"key_release_event\" handler=\"on_window_main_key_release_event\"/>\n"
		"    <child>\n"
		"      <object class=\"GtkVBox\" id=\"vbox1\">\n"
		"        <property name=\"visible\">True</property>\n"
		"        <property name=\"orientation\">vertical</property>\n"
		"        <child>\n"
		"          <object class=\"GtkLabel\" id=\"label1\">\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"label\" translatable=\"yes\">&lt;b&gt;BASEBUILD&lt;/b&gt;</property>\n"
		"            <property name=\"use_markup\">True</property>\n"
		"          </object>\n"
		"          <packing>\n"
		"            <property name=\"position\">0</property>\n"
		"          </packing>\n"
		"        </child>\n"
		"        <child>\n"
		"          <object class=\"GtkButton\" id=\"button_quit\">\n"
		"            <property name=\"label\" translatable=\"yes\">quit</property>\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"can_focus\">True</property>\n"
		"            <property name=\"receives_default\">True</property>\n"
		"            <signal name=\"clicked\" handler=\"on_button_quit_clicked\"/>\n"
		"          </object>\n"
		"          <packing>\n"
		"            <property name=\"expand\">False</property>\n"
		"            <property name=\"position\">1</property>\n"
		"          </packing>\n"
		"        </child>\n"
		"      </object>\n"
		"    </child>\n"
		"  </object>\n"
		"</interface>\n"
		"\n";

	
	if( Config.ComboboxChoiceGlade == CHOICE_GLADE_FILE_DEFAULT ) {
		
		if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
			fprintf( fp, "%s", BufGlade );
		
			fclose( fp );
		}
		if( NULL != PathNameFile ) {
			g_free( PathNameFile );
			PathNameFile = NULL;
		}
	}
	else if( Config.ComboboxChoiceGlade == CHOICE_GLADE_FILE_OK ) {
	
		gchar	*Dest = build_get_dest_pathnamefile_glade();
		
		libutils_copy_src_to_dest( Config.IncludePathNameFileGlade, Dest );
		
		g_free( Dest );
		Dest = NULL;
	}
}
// 
// SRC/MAKEFILE.AM
// 
void BuildWrite_src_makefile_am( gchar *Path, gchar *Name, gchar *Ext, VAR_BUILD_SRC *VarBuildSrc )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );

	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
	
		fprintf( fp, "#\n# %s/Makefile.am with BaseBuild\n#\n", VarBuildSrc->Name);
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");

		if( TRUE == VarBuild.Bool_lib_gtk ||  TRUE == VarBuild.Bool_lib_glib ) {
			fprintf( fp, "\nINCLUDES = \\\n");
			fprintf( fp, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
			fprintf( fp, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
			fprintf( fp, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarBuild.NameProject);
			fprintf( fp, "	@PACKAGE_CFLAGS@\n");
			fprintf( fp, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
			fprintf( fp, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
			fprintf( fp, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
			fprintf( fp, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarBuild.NameProject);
		}
		fprintf( fp, "\nbin_PROGRAMS=%s\n", VarBuildSrc->Exec);

		if (TRUE == VarBuild.Bool_import_glade_translate) {
			fprintf( fp, "%s_SOURCES=main.c translate.c global.h\n", VarBuildSrc->Exec);
		}
		else {
			fprintf( fp, "%s_SOURCES=main.c global.h\n", VarBuildSrc->Exec);
		}
		if (TRUE == VarBuild.Bool_dossier_lib_statique) {
			fprintf( fp, "\n%s_CPPFLAGS=-I${top_srcdir}/%s\n", VarBuildSrc->Exec, VarBuild.NameLib);
		}
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "\ndatadir = @datadir@\n");
			fprintf( fp, "localedir = $(datadir)/locale\n");
			fprintf( fp, "DEFS = -DLOCALEDIR=\"$(localedir)\" @DEFS@\n");
		}
		if (TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_dossier_lib_statique || TRUE == VarBuild.Bool_dossier_po || TRUE == VarBuild.Bool_lib_glib ) {
			fprintf( fp, "\n%s_LDADD =", VarBuildSrc->Exec);
			if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
				fprintf( fp, "@PACKAGE_LIBS@");
			}
			if (TRUE == VarBuild.Bool_dossier_po) {
				fprintf( fp, " $(INTLLIBS)");
			}
			if (TRUE == VarBuild.Bool_dossier_lib_statique) {
				fprintf( fp, " ${top_builddir}/%s/%s.a", VarBuild.NameLib, VarBuild.NameLib);
			}
			fprintf( fp, "\n" );
		}

		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// SRC/main.c
// 
void BuildWrite_SRC_C_file( gchar *Path, gchar *Name, gchar *Ext, VAR_BUILD_SRC *VarBuildSrc )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	gchar		*NameProject = libutils_string_toupper( Config.NameProject );
	gboolean	BoolWithGLIB = FALSE;
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		// HEADER
				
		fprintf( fp, " /*\n" );
		fprintf( fp, " * file      : src/main.c\n" );
		fprintf( fp, " * project   : %s\n", Config.NameProject );
		fprintf( fp, " * with      : Gtk-2\n" );
		fprintf( fp, " *\n" );
		fprintf( fp, " * copyright : (C) 2012 by %s\n", Config.NameAuthors );
		fprintf( fp, " *\n" );
		fprintf( fp, " * %s - INDIQUEZ ICI CE QUE FAIT LE PROGRAMME\n", NameProject );
		fprintf( fp, " * GNU General Public License\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * This file is part of %s.\n", NameProject );
		fprintf( fp, " * \n" );
		fprintf( fp, " * %s is free software: you can redistribute it and/or modify\n", NameProject );
		fprintf( fp, " * it under the terms of the GNU General Public License as published by\n" );
		fprintf( fp, " * the Free Software Foundation, either version 3 of the License, or\n" );
		fprintf( fp, " * at your option) any later version.\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * %s is distributed in the hope that it will be useful,\n", NameProject );
		fprintf( fp, " * but WITHOUT ANY WARRANTY; without even the implied warranty of\n" );
		fprintf( fp, " * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" );
		fprintf( fp, " * GNU General Public License for more details.\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * You should have received a copy of the GNU General Public License\n" );
		fprintf( fp, " * along with %s.  If not, see <http://www.gnu.org/licenses/>.\n", NameProject );
		fprintf( fp, " */\n" );
		fprintf( fp, "\n");
		fprintf( fp, "#ifdef HAVE_CONFIG_H\n");
		fprintf( fp, "	#include \"../config.h\"\n");
		fprintf( fp, "#endif\n");
		fprintf( fp, "\n");
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "#ifdef ENABLE_NLS\n");
			fprintf( fp, "	#include <libintl.h>\n");
			fprintf( fp, "	#define _(String) gettext (String)\n");
			fprintf( fp, "#endif\n");
		}
		fprintf( fp, "\n");
		
		if( TRUE == Config.BoolRadioButonGui ) {
			
			// PROGRAMM GUI
			
			if( TRUE == VarBuild.Bool_lib_gtk ) {
			
				// HEADER
				
				fprintf( fp, "#include <gtk/gtk.h>\n");
				fprintf( fp, "#include <gdk/gdkkeysyms.h>\n" );
				if( TRUE == VarBuild.Bool_lib_glib ) {
					fprintf( fp, "#include <glib.h>\n" );
				}
				fprintf( fp, "\n");
				fprintf( fp, "#include <stdio.h>\n");
				fprintf( fp, "#include <stdlib.h>\n");
				fprintf( fp, "\n");
				if (TRUE == VarBuild.Bool_dossier_lib_statique) {
					fprintf( fp, "#ifdef ENABLE_STATIC_LIBRARY\n");
					fprintf( fp, "	#include \"../%s/lib.h\"\n", VarBuild.NameLib);
					fprintf( fp, "#endif\n");
					fprintf( fp, "\n");
				}
				fprintf( fp, "#include \"global.h\"\n");
				fprintf( fp, "\n");
				fprintf( fp, "\n");
				
				switch( Config.ComboboxChoiceGlade ) {
				case CHOICE_GLADE_FILE_NONE :
				
					// GLADE VIA GTK
				
					fprintf( fp, "/* gint main( gint argc, gchar *argv[], gchar **envp )\n" );
					fprintf( fp, " *\n" );
					fprintf( fp, " * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n" );
					fprintf( fp, " * argv  designe le vecteur contenant les differents arguments\n" );
					fprintf( fp, " * envp  designe le vecteur contenant les informations sur l'environnement\n" );
					fprintf( fp, " */\n" );
					fprintf( fp, "gint main( gint argc, gchar *argv[], gchar **envp )\n" );
					fprintf( fp, "{\n" );
					fprintf( fp, "\tGtkWidget *p_window = NULL;\n" );
					fprintf( fp, "\tGtkWidget *p_button = NULL;\n" );
					fprintf( fp, "\n" );
					fprintf( fp, "\t// Initialisation de GTK+\n" );
					fprintf( fp, "\tgtk_init( &argc, &argv );\n" );
					fprintf( fp, "\n" );
					fprintf( fp, "\t// Creation de la fenetre principale de notre application\n" );
					fprintf( fp, "\tp_window = gtk_window_new( GTK_WINDOW_TOPLEVEL );\n" );
					fprintf( fp, "\tgtk_window_resize( GTK_WINDOW(p_window), 150, 50 );\n" );
					fprintf( fp, "\tgtk_window_set_position( GTK_WINDOW(p_window),GTK_WIN_POS_CENTER );\n" );
					fprintf( fp, "\tg_signal_connect( G_OBJECT( p_window ), \"destroy\", G_CALLBACK( gtk_main_quit ), NULL );\n" );
					fprintf( fp, "\n" );
					fprintf( fp, "\t// Creation du bouton\n" );
					if (TRUE == VarBuild.Bool_dossier_po) {
						fprintf( fp, "\tp_button = gtk_button_new_with_mnemonic( _(\"Hello  !\") );\n" );
					} else {
						fprintf( fp, "\tp_button = gtk_button_new_with_mnemonic( \"Hello  !\" );\n" );
					}
					fprintf( fp, "\tgtk_container_add( GTK_CONTAINER( p_window ), p_button );\n" );
					fprintf( fp, "\tg_signal_connect( G_OBJECT( p_button ), \"clicked\", G_CALLBACK( gtk_main_quit ), NULL );\n" );
					fprintf( fp, "\n" );
					fprintf( fp, "\t// Affichage de la fenetre principale\n" );
					fprintf( fp, "\tgtk_widget_show_all( p_window );\n" );
					fprintf( fp, "\n" );
					fprintf( fp, "\t// Lancement de la boucle principale\n" );
					fprintf( fp, "\tgtk_main();\n" );
					fprintf( fp, "\treturn( EXIT_SUCCESS );\n" );
					fprintf( fp, "}\n" );
					fprintf( fp, "\n" );
					break;
			
				case CHOICE_GLADE_FILE_DEFAULT :
				case CHOICE_GLADE_FILE_OK :
					// 
					fprintf( fp, "GtkBuilder	*GtkBuilderProjet = NULL;\n");
					fprintf( fp, "GtkWidget	*WindMain = NULL;\n");
					fprintf( fp, "\n");
					fprintf( fp, "KEYS keys = {\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDKPress\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDK_Control_L_R\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDK_Control_A\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDK_Shift_L_R\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDK_Shift_L\n");
					fprintf( fp, "	FALSE,		// gboolean	BoolGDK_Shift_R\n");
					fprintf( fp, "	0,		// guint	keyval\n");
					fprintf( fp, "};\n");
					fprintf( fp, "\n");
					
					if( CHOICE_GLADE_FILE_OK == Config.ComboboxChoiceGlade || CHOICE_GLADE_FILE_DEFAULT == Config.ComboboxChoiceGlade ) {
						
						gchar *PathNameFileGlade = build_get_dest_pathnamefile_glade();
						
						Proto_init( PathNameFileGlade );
						fprintf( fp, "%s", VarProto.GstrMain->str );
						
						g_free( PathNameFileGlade );
						PathNameFileGlade = NULL;
					}
					else {
						gchar	*Buf_choice_default =

						"// \n"
						"// \n"
						"gboolean on_window_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )\n"
						"{\n"
						"	keys.BoolGDKPress = TRUE;\n"
						"	keys.keyval       = kevent->keyval;\n"
						"	\n"
						"	if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {\n"
						"		keys.BoolGDK_Control_L_R = TRUE;\n"
						"	}\n"
						"	else if( kevent->state == 20 || kevent->state == 21 ) {\n"
						"		if( kevent->keyval == 65 || kevent->keyval == 97 ) {\n"
						"			keys.BoolGDK_Control_A = TRUE;\n"
						"		}\n"
						"	}\n"
						"	\n"
						"	return FALSE;\n"
						"}\n"
						"// \n"
						"// \n"
						"gboolean on_window_main_key_release_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )\n"
						"{\n"
						"	keys.BoolGDKPress        = FALSE;\n"
						"	keys.BoolGDK_Control_L_R = FALSE;\n"
						"	keys.BoolGDK_Control_A   = FALSE;\n"
						"	keys.keyval              = 0;\n"
						"	\n"
						"	return FALSE;\n"
						"}\n"
						"// \n"
						"// \n"
						"gboolean on_window_main_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n"
						"{\n"
						// if (TRUE == VarBuild.Bool_dossier_po) {
						// 	"#ifdef ENABLE_NLS\n"
						// 	"	g_print(_(\"End of Program from delete_event\\n\"));\n"
						// 	"#endif\n"
						// }
						"	gtk_main_quit ();\n"
						"	return FALSE;\n"
						"}\n"
						"// \n"
						"// \n"
						"gboolean on_window_main_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n"
						"{\n"
						// if (TRUE == VarBuild.Bool_dossier_po) {
						// 	"#ifdef ENABLE_NLS\n"
						// 	"	g_print(_(\"End of Program from destroy_event\\n\"));\n"
						// 	"#endif\n"
						// }
						"	gtk_main_quit ();\n"
						"	return FALSE;\n"
						"}\n"
						"// \n"
						"// \n"
						"void on_button_quit_clicked (GtkButton *button, gpointer user_data)\n"
						"{\n"
						// if (TRUE == VarBuild.Bool_dossier_po) {
						// 	"#ifdef ENABLE_NLS\n"
						// 	"	g_print(_(\"End of Program from button\\n\\n\"));\n"
						// 	"#endif\n"
						// }
						"	gtk_main_quit ();\n"
						"}\n";
						
						fprintf( fp, "%s", Buf_choice_default );
					}
					
					break;

				}
				
				if( CHOICE_GLADE_FILE_OK == Config.ComboboxChoiceGlade || CHOICE_GLADE_FILE_DEFAULT == Config.ComboboxChoiceGlade ) {
					
					gchar	*Buf_choice_ok_and_default =
					
					"\n"
					"/* gint main (gint argc, gchar *argv[], gchar **envp)\n"
					" *\n"
					" * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n"
					" * argv  designe le vecteur contenant les differents arguments\n"
					" * envp  designe le vecteur contenant les informations sur l'environnement\n"
					" */\n"
					"gint main( gint argc, gchar *argv[], gchar **envp )\n"
					"{\n"
					"	GError	*p_err = NULL;\n"
					"	gchar	*CurrentDir = g_get_current_dir ();\n"
					"	gchar	*PathCurrentDir = NULL;\n"
					"	gchar	*PathShareProjet = NULL;\n"
					"	gchar	*Path = NULL;\n"
					"	gchar	*PackageVersion = NULL;\n"
					"\n"
					"	g_print( \"%s :: %s (line = %d)\\n\", __FILE__, __FUNCTION__, __LINE__ );\n"
					"	g_print( \"\\n\" );\n"
					"	g_print( \"***************************\\n\" );\n"
					"	g_print( \"%s %s\\n\", PACKAGE, VERSION );\n"
					"	g_print( \"***************************\\n\" );\n"
					"	g_print( \"%s %s compiled at %s %s\\n\", PACKAGE, VERSION, __DATE__, __TIME__ );\n"
					"	g_print( \"Compiler: gcc %s\\n\", __VERSION__ );\n"
					"	g_print( \"***************************\\n\" );\n"
					"	g_print( \"Gtk version  = %d.%d.%d\\n\", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION );\n"
					"	g_print( \"Glib version = %d.%d.%d\\n\", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION );\n"
					"	g_print( \"***************************\\n\\n\" );\n"
					"#ifdef ENABLE_NLS\n"
					"	g_print( \"ENABLE_NLS OK\\n\" );\n"
					"	g_print( \"\\tGETTEXT_PACKAGE    = %s\\n\", GETTEXT_PACKAGE );\n"
					"	g_print( \"\\tLOCALE_DIR         = %s\\n\", LOCALE_DIR );\n"
					"\n"
					"	setlocale( LC_ALL, \"\" );\n"
					"	bindtextdomain( GETTEXT_PACKAGE, LOCALE_DIR );\n"
					"	bind_textdomain_codeset( GETTEXT_PACKAGE, \"UTF-8\" );\n"
					"	textdomain( GETTEXT_PACKAGE );\n"
					"#else\n"
					"	// g_error( \"ENABLE_NLS IS NOT OK \\n \\n \" );\n"
					"#endif\n"
					"	gtk_set_locale();\n"
					"	gtk_init( &argc, &argv );\n"
					"\n"
					"	if( NULL == ( GtkBuilderProjet = gtk_builder_new() )) {\n"
					"		return( EXIT_FAILURE );\n"
					"	}\n"
					"	gtk_builder_set_translation_domain( GtkBuilderProjet, NULL );\n"
					"\n"
					"	PathCurrentDir = g_strdup_printf( \"%s/glade/%s\", CurrentDir, PACKAGE_NAME_GLADE );\n"
					"	g_free( CurrentDir );\n"
					"	CurrentDir = NULL;\n"
					"	PathShareProjet = g_strdup_printf( \"%s/%s/glade/%s\", DATA_DIR, PACKAGE_NAME, PACKAGE_NAME_GLADE );\n"
					"\n"
					"	if( FALSE == g_file_test( PathCurrentDir, G_FILE_TEST_EXISTS ) && FALSE == g_file_test( PathShareProjet, G_FILE_TEST_EXISTS )) {\n"
					"		g_print( \"!---------------------------------------------------------------------------------------------------\\n\" );\n"
					"		g_print( \"! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\\n\", PathCurrentDir );\n"
					"		g_print( \"!---------------------------------------------------------------------------------------------------\\n\" );\n"
					"		g_print( \"! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\\n\", PathShareProjet );\n"
					"		g_print( \"!---------------------------------------------------------------------------------------------------\\n\" );\n"
					"\n"
					"		g_free( PathCurrentDir );\n"
					"		PathCurrentDir = NULL;\n"
					"		g_free( PathShareProjet );\n"
					"		PathShareProjet = NULL;\n"
					"\n"
					"		return( EXIT_FAILURE );\n"
					"	}\n"
					"	else if( TRUE == g_file_test( PathCurrentDir, G_FILE_TEST_EXISTS )) {\n"
					"\n"
					"		Path = PathCurrentDir;\n"
					"	}\n"
					"	else if( TRUE == g_file_test( PathShareProjet, G_FILE_TEST_EXISTS )) {\n"
					"\n"
					"		Path = PathShareProjet;\n"
					"	}\n"
					"	g_print( \"\\nPATHNAME FILE %s: %s\\n\\n\", PACKAGE_NAME_GLADE, Path );\n"
					"	if( gtk_builder_add_from_file( GtkBuilderProjet, Path, &p_err) <= 0 ) {\n"
					"		g_warning( \"Couldn't load builder file: %s\", p_err->message );\n"
					"		g_error_free( p_err );\n"
					"\n"
					"		g_free( PathCurrentDir );\n"
					"		PathCurrentDir = NULL;\n"
					"		g_free( PathShareProjet );\n"
					"		PathShareProjet = NULL;\n"
					"		Path = NULL;\n"
					"\n"
					"		return( EXIT_FAILURE );\n"
					"	}\n"
					"	g_free( PathCurrentDir );\n"
					"	PathCurrentDir = NULL;\n"
					"	g_free( PathShareProjet );\n"
					"	PathShareProjet = NULL;\n"
					"	Path = NULL;\n"
					"\n"
					"	gtk_builder_set_translation_domain( GtkBuilderProjet, gtk_set_locale ());\n"
					"	gtk_builder_connect_signals( GtkBuilderProjet, NULL );\n"
					" ";
					
					fprintf( fp, "%s", Buf_choice_ok_and_default );
					
					if (TRUE == VarBuild.Bool_import_glade_file) {
						fprintf( fp, "\tWindMain = GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet, \"%s\" ));\n", Proto_get_id ());
					}
					else {
						fprintf( fp, "\tWindMain = GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet, \"window_main\" ));\n");
					}
					fprintf( fp, "\n");
					fprintf( fp, "\tPackageVersion = g_strdup_printf( \"%s  -  %%s\", VERSION );\n", Config.NameProject);
					fprintf( fp, "\tgtk_window_set_title( GTK_WINDOW( WindMain ), PackageVersion );\n");
					fprintf( fp, "\tg_free( PackageVersion );\n");
					fprintf( fp, "\tPackageVersion = NULL;\n");
					fprintf( fp, "\n");
					
					fprintf( fp, "\tgtk_widget_show( WindMain );\n");
					if (TRUE == VarBuild.Bool_dossier_po) {
						fprintf( fp, "#ifdef ENABLE_NLS\n");
						fprintf( fp, "\tprintf( _(\"Chaine a traduire\\n\") );\n");
						fprintf( fp, "#endif\n");
					}
					fprintf( fp, "\tgtk_main();\n");
					fprintf( fp, "\n");
					fprintf( fp, "\texit( EXIT_SUCCESS );\n");
					fprintf( fp, "}\n\n");
					
				}
			}
			else {	
				BoolWithGLIB = VarBuild.Bool_lib_glib;
			}
		}
		else {
			BoolWithGLIB = VarBuild.Bool_lib_glib;
		}
		
		// WITH GLIB
		if( TRUE == BoolWithGLIB ) {
			fprintf( fp, "#include <glib.h>\n" );
			fprintf( fp, "\n");
			fprintf( fp, "#include <stdio.h>\n");
			fprintf( fp, "#include <stdlib.h>\n");
			fprintf( fp, "\n");
			if (TRUE == VarBuild.Bool_dossier_lib_statique) {
				fprintf( fp, "#ifdef ENABLE_STATIC_LIBRARY\n");
				fprintf( fp, "	#include \"../%s/lib.h\"\n", VarBuild.NameLib);
				fprintf( fp, "#endif\n");
				fprintf( fp, "\n");
			}
			fprintf( fp, "\n");
		
			fprintf( fp, "/* gint main( gint argc, gchar *argv[], gchar **envp )\n" );
			fprintf( fp, " *\n" );
			fprintf( fp, " * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n" );
			fprintf( fp, " * argv  designe le vecteur contenant les differents arguments\n" );
			fprintf( fp, " * envp  designe le vecteur contenant les informations sur l'environnement\n" );
			fprintf( fp, " */\n" );
			fprintf( fp, "gint main( gint argc, gchar *argv[], gchar **envp )\n" );
			fprintf( fp, "{\n" );
			fprintf( fp, "\tgchar	*buffer = g_strdup( \"With GLIB\\n\" );\n\n" );
			fprintf( fp, "\tg_print( \"%%s :: %%s (line = %%d)\\n\", __FILE__, __FUNCTION__, __LINE__ );\n");
			fprintf( fp, "\tg_print( \"buffer = %%s\\n\", buffer );\n");
			fprintf( fp, "\tg_free( buffer );\n");
			fprintf( fp, "\tbuffer = NULL;\n");
			if( TRUE == VarBuild.Bool_dossier_po ) {
				fprintf( fp, "#ifdef ENABLE_NLS\n");
				fprintf( fp, "\tg_print( _(\"Chaine a traduire depuis %s/\\n\") );\n", VarBuildSrc->Name);
				fprintf( fp, "#endif\n");
			}
			fprintf( fp, "\n");
			if( TRUE == VarBuild.Bool_dossier_lib_statique ) {
				fprintf( fp, "#ifdef ENABLE_STATIC_LIBRARY\n");
				fprintf( fp, "\tlibH_print_mess( \"Appel fonction librairie statique depuis %s = ok\\n\" );\n", VarBuildSrc->Name);
				fprintf( fp, "#endif\n");
			}
			fprintf( fp, "\treturn( EXIT_SUCCESS );\n" );
			fprintf( fp, "}\n" );
			fprintf( fp, "\n");
		}
		// WITHOUT GLIB
		else if( FALSE == Config.BoolRadioButonGui ) {

			fprintf( fp, "#include <stdio.h>\n");
			fprintf( fp, "#include <stdlib.h>\n");
			fprintf( fp, "\n");
			if (TRUE == VarBuild.Bool_dossier_lib_statique) {
				fprintf( fp, "#ifdef ENABLE_STATIC_LIBRARY\n");
				fprintf( fp, "	#include \"../%s/lib.h\"\n", VarBuild.NameLib);
				fprintf( fp, "#endif\n");
				fprintf( fp, "\n");
			}
			fprintf( fp, "\n");
			
			fprintf( fp, "/* int main( int argc, char *argv[], char **envp )\n" );
			fprintf( fp, " *\n" );
			fprintf( fp, " * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n" );
			fprintf( fp, " * argv  designe le vecteur contenant les differents arguments\n" );
			fprintf( fp, " * envp  designe le vecteur contenant les informations sur l'environnement\n" );
			fprintf( fp, " */\n" );
			fprintf( fp, "int main( int argc, char *argv[], char **envp )\n" );
			fprintf( fp, "{\n" );			
			fprintf( fp, "\tprintf (\"%%s :: %%s (line = %%d)\\n\", __FILE__, __FUNCTION__, __LINE__);\n");
			if( TRUE == VarBuild.Bool_dossier_po ) {
				fprintf( fp, "#ifdef ENABLE_NLS\n");
				fprintf( fp, "\tprintf (_(\"Chaine a traduire depuis %s/\\n\"));\n", VarBuildSrc->Name);
				fprintf( fp, "#endif\n");
			}
			fprintf( fp, "\n");
			if( TRUE == VarBuild.Bool_dossier_lib_statique ) {
				fprintf( fp, "#ifdef ENABLE_STATIC_LIBRARY\n");
				fprintf( fp, "\tlibH_print_mess (\"Appel fonction librairie statique depuis %s = ok\\n\");\n", VarBuildSrc->Name);
				fprintf( fp, "#endif\n");
			}
			fprintf( fp, "\treturn( EXIT_SUCCESS );\n" );
			fprintf( fp, "}\n" );
			fprintf( fp, "\n");
		}
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
	if( NULL != NameProject ) {
		g_free( NameProject );
		NameProject = NULL;
	}
}
// 
// GLOBAL.H
// 
void BuildWrite_GLOBAL_H_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	gchar		*NameProject = libutils_string_toupper( Config.NameProject );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, " /*\n" );
		fprintf( fp, " * file      : src/main.c\n" );
		fprintf( fp, " * project   : %s\n", Config.NameProject );
		fprintf( fp, " * with      : Gtk-2\n" );
		fprintf( fp, " *\n" );
		fprintf( fp, " * copyright : (C) 2012 by %s\n", Config.NameAuthors );
		fprintf( fp, " *\n" );
		fprintf( fp, " * %s - INDIQUEZ ICI CE QUE FAIT LE PROGRAMME\n", NameProject );
		fprintf( fp, " * GNU General Public License\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * This file is part of %s.\n", NameProject );
		fprintf( fp, " * \n" );
		fprintf( fp, " * %s is free software: you can redistribute it and/or modify\n", NameProject );
		fprintf( fp, " * it under the terms of the GNU General Public License as published by\n" );
		fprintf( fp, " * the Free Software Foundation, either version 3 of the License, or\n" );
		fprintf( fp, " * at your option) any later version.\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * %s is distributed in the hope that it will be useful,\n", NameProject );
		fprintf( fp, " * but WITHOUT ANY WARRANTY; without even the implied warranty of\n" );
		fprintf( fp, " * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" );
		fprintf( fp, " * GNU General Public License for more details.\n" );
		fprintf( fp, " * \n" );
		fprintf( fp, " * You should have received a copy of the GNU General Public License\n" );
		fprintf( fp, " * along with %s.  If not, see <http://www.gnu.org/licenses/>.\n", NameProject );
		fprintf( fp, " */\n" );
		fprintf( fp, "\n");
		fprintf( fp, "\n");
		fprintf( fp, "#ifndef __global_h__\n");
		fprintf( fp, "#define __global_h__ 1\n");
		fprintf( fp, "\n");

		if (TRUE == VarBuild.Bool_lib_gtk) {
			fprintf( fp, "extern	GtkBuilder	*GtkBuilderProjet;\n");
			fprintf( fp, "extern	GtkWidget	*WindMain;\n");
			fprintf( fp, "\n");
			fprintf( fp, "#define GLADE_GET_OBJECT(OBJ) gtk_builder_get_object (GtkBuilderProjet, OBJ)\n");
			fprintf( fp, "\n");
			fprintf( fp, "/*\n");
			fprintf( fp, "*---------------------------------------------------------------------------\n");
			fprintf( fp, "* DEBUG\n");
			fprintf( fp, "*---------------------------------------------------------------------------\n");
			fprintf( fp, "*/\n");
			fprintf( fp, "#define PRINTINT(str,num)	g_print (\"%%s = %%d\\n\", str, num)\n");
			fprintf( fp, "#define PRINTBOOL(str,bool)	g_print (\"%%s = %%s\\n\", str, bool == TRUE ? \"TRUE\" : \"FALSE\")\n");
			fprintf( fp, "#define PRINT_FUNC_LF()		g_print (\"%%s :: %%s (line = %%d) \\n\", __FILE__, __FUNCTION__, __LINE__)\n");
			fprintf( fp, "#define PRINT(str)		g_print (\"%%s :: %%s(line = %%d)\\n\t%%s\\n\", __FILE__, __FUNCTION__, __LINE__, str)\n");
			fprintf( fp, "\n");
			fprintf( fp, "// /usr/include/gtk-2.0/gdk/gdkkeysyms.h\n");
			fprintf( fp, "typedef struct {\n");
			fprintf( fp, "	gboolean	BoolGDKPress;		// \n");
			fprintf( fp, "	gboolean	BoolGDK_Control_L_R;	// \n");
			fprintf( fp, "	gboolean	BoolGDK_Control_A;	// \n");
			fprintf( fp, "	gboolean	BoolGDK_Shift_L_R;	// \n");
			fprintf( fp, "	gboolean	BoolGDK_Shift_L;	// \n");
			fprintf( fp, "	gboolean	BoolGDK_Shift_R;	// \n");
			fprintf( fp, "	guint		keyval;			// \n");
			fprintf( fp, "} KEYS;\n");
			fprintf( fp, "\n");
		}
		
		fprintf( fp, "#endif\n");
		fprintf( fp, "\n");
	
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
	if( NULL != NameProject ) {
		g_free( NameProject );
		NameProject = NULL;
	}
}
// 
// SRC/translate.c
// 
void BuildWrite_SRC_TRANSLATE_C_file( gchar *Path, gchar *Name, gchar *Ext, VAR_BUILD_SRC *VarBuildSrc )
{
	if (TRUE == VarBuild.Bool_import_glade_file && TRUE == VarBuild.Bool_import_glade_translate) {
			
		gchar	*PathnameFileGlade = build_get_dest_pathnamefile_glade();
		
		if( TRUE == ProtoTranslate_init( PathnameFileGlade )) {
		// if( NULL != VarProto.GstrTranslate ) {
			WinVte_window_write_va( "\t", VarBuildSrc->PathName, "/translate.c\n", NULL );
			BuildWrite_file( Path, Name, Ext, VarProto.GstrTranslate->str );
		}
		g_free( PathnameFileGlade );
		PathnameFileGlade = NULL;
	}
}
// 
// MAN/MAKEFILE.AM
// 
void BuildWrite_man_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# man/Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		fprintf( fp, "man1_MANS = %s.1.gz\n", VarBuild.NameProject);
		fprintf( fp, "EXTRA_DIST = compilate_manpage.txt %s.1.gz\n", VarBuild.NameProject);
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// MAN/NOM_PROJET.1
// 
void BuildWrite_MAN_file (void)
{
	FILE		*fp = NULL;
	gchar		*NameManZip = g_strdup_printf ("%s.1", VarBuild.NameProject);
	gchar		*PathNameFile = g_strdup_printf( "%s/%s", VarBuild.PathNameMan, NameManZip );
	// gchar		*LineCommand = NULL;
 	// gint		 RetSystem;
	
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, ".\\\" %s_man\n", VarBuild.NameProject);
		fprintf( fp, ".\\\" Copyright (C) 2010\n");
		fprintf( fp, ".\\\"\n");
		fprintf( fp, "\n");
		fprintf( fp, ".TH %s 1 \"Sat, 01 May 2010\" %s \"Page d'aide de: %s\"\n", VarBuild.NameProject, VarBuild.VersionProject, VarBuild.NameProject);
		fprintf( fp, "\n");
		fprintf( fp, ".SH NOM\n");
		fprintf( fp, "\\fB%s\\fP \\- GTK+ Implementation of the GNU.\n", VarBuild.NameProject);
		
		fclose( fp );
	}
	
	// CONSTRUCTION DU FICHIER ZIP MANPAGE
	// LineCommand = g_strdup_printf( "gzip --best %s", PathNameFile );
	// RetSystem = system( LineCommand );
	// g_free( LineCommand );
	// LineCommand = NULL;
	conv_with_args( "gzip", "--best", PathNameFile, NULL );

	
	g_free( PathNameFile );
	PathNameFile = NULL;

	g_free( NameManZip );
	NameManZip = NULL;
	
	// FICHIER D AIDE
	PathNameFile = g_strdup_printf( "%s/compilate_manpage.txt", VarBuild.PathNameMan );
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "\ngzip --best ./%s.1\n\n", VarBuild.NameProject );
		
		fclose( fp );
	}
	
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// PIXMAPS/MAKEFILE.AM
// 
void BuildWrite_pixmaps_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# pixmaps/Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		fprintf( fp, "pixmaps_DATA = test%s.png\n", VarBuild.NameProject);
		fprintf( fp, "pixmapsdir = $(datadir)/pixmaps\n");
		fprintf( fp, "EXTRA_DIST = $(pixmaps_DATA)\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// COPIE FICHIERS /usr/share/pixmaps/$VarBuild.NameProject/testbasebuild.png
// 
void BuildWrite_PIXMAPS_file( void )
{
	gchar	*CurrentDir = g_get_current_dir ();
	gchar	*PathCurrentDir = NULL;
	gchar	*LineCommand = NULL;
	gint	 RetSystem;
	
	// TEST SOURCE FILE
	PathCurrentDir = g_strdup_printf ("%s/pixmaps/testbasebuild.png", CurrentDir);
	if (FALSE == libutils_test_file_exist (PathCurrentDir)) {
		g_free (PathCurrentDir);
		PathCurrentDir = NULL;
		PathCurrentDir = g_strdup_printf ("%s/pixmaps/testbasebuild.png", DATA_DIR);
		if (FALSE == libutils_test_file_exist (PathCurrentDir)) {
			g_free (PathCurrentDir);
			PathCurrentDir = NULL;
			return;
		}
	}
	
	// SOURCE IN: PathCurrentDir
	// DEST IN:   VarBuild.PathNamePixmaps
	LineCommand = g_strdup_printf ("cp %s %s/test%s.png", PathCurrentDir, VarBuild.PathNamePixmaps, VarBuild.NameProject);
	RetSystem = system (LineCommand);
	g_free (LineCommand);
	LineCommand = NULL;
	g_free (CurrentDir);
	CurrentDir = NULL;
}
// 
// MENU/MAKEFILE.AM
// 
void BuildWrite_menu_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# menu/Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		fprintf( fp, "menu_DATA = %s.desktop\n", VarBuild.NameProject);
		fprintf( fp, "menudir = $(datadir)/applications\n");
		fprintf( fp, "EXTRA_DIST = $(menu_DATA)\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// RETOURNE LA CATEGORIE ACTIVE
//
gchar *BuildWrite_get_entry_categories_item (void)
{
	*VarBB.StrCategoriesEntry = '\0';
	g_sprintf (&VarBB.StrCategoriesEntry[0], "Categories=Application;%s\n", gtk_combo_box_get_active_text (GTK_COMBO_BOX(VarBB.Adr_combobox_categories)));
	return (VarBB.StrCategoriesEntry);
}
// 
// MENU/NOM_PROJET.1.gz
// 
void BuildWrite_MENU_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "[Desktop Entry]\n");
		fprintf( fp, "Version=%s\n", VarBuild.VersionProject);
		fprintf( fp, "Name=%s\n", VarBuild.NameProject);
		fprintf( fp, "Name[fr]=%s\n", VarBuild.NameProject);
		fprintf( fp, "GenericName[fr]=%s\n", VarBuild.NameProject);
		fprintf( fp, "Comment=%s. My new application with basebuild.\n", VarBuild.NameProject);
		fprintf( fp, "Icon=test%s.png\n", VarBuild.NameProject);
		fprintf( fp, "Type=Application\n");
		fprintf( fp, "Exec=%s\n", VarBuild.NameProject);
		fprintf( fp, "Terminal=false\n");
		fprintf( fp, "StartupNotify=true\n");
		fprintf( fp, "%s", BuildWrite_get_entry_categories_item ());
		//	
		//	http://standards.freedesktop.org/menu-spec/1.0/apa.html
		//	AudioVideo
		//	Audio
		//	Video
		//	Development
		//	Education
		//	Game
		//	Graphics
		//	Network
		//	Office
		//	Settings
		//	System
		//	Utility
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// MIME/MAKEFILE.AM
// 
void BuildWrite_mime_makefile_am( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# mime/Makefile.am with BaseBuild\n#\n");
		fprintf( fp, "AUTOMAKE_OPTIONS= gnu \n");
		fprintf( fp, "EXTRA_DIST = %s\n", VarBuild.NameProject);
		fprintf( fp, "mime_DATA = %s\n", VarBuild.NameProject);
		fprintf( fp, "mimedir = $(DESTDIR)/$(libdir)/mime/packages\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// MIME/$VarBuild.NameProject
// 
void BuildWrite_MIME_file( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "application/ogg; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "audio/basic; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "audio/mpeg; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "udio/x-aiff; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "audio/x-mp3; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "audio/x-wav; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "application/x-flac; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		fprintf( fp, "audio/x-flac; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarBuild.NameProject, VarBuild.NameProject);
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// CONFIGURE.IN
// 
void BuildWrite_configure_in( gchar *Path, gchar *Name, gchar *Ext )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup_printf( "%s/%s%s", Path, Name, Ext );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#\n# configure.in with BaseBuild\n#\n");
		fprintf( fp, "#                                               -*- Autoconf -*-\n");
		fprintf( fp, "# Process this file with autoconf to produce a configure script.\n");
	
		fprintf( fp, "AC_INIT([%s],\n\t[%d.%d.%d],\n\t[http://www.xcfa.tuxfamily.org/],\n\t[%s],\n\t[http://www.xcfa.tuxfamily.org/])\n",
				gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project)),
				gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_A)),
				gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_B)),
				gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_C)),
				gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project))
				);
		
		fprintf( fp, "AM_INIT_AUTOMAKE\n");
		fprintf( fp, "AC_CONFIG_SRCDIR([src/main.c])\n");
		fprintf( fp, "AC_CONFIG_HEADER([config.h])\n");

		fprintf( fp, "\n# Checks for programs.\n");
		fprintf( fp, "AC_PROG_CXX\n");
		fprintf( fp, "AC_PROG_CC\n");
		fprintf( fp, "AC_PROG_CPP\n");
		fprintf( fp, "AC_PROG_INSTALL\n");
		fprintf( fp, "# AC_PROG_LN_S\n");
		fprintf( fp, "AC_PROG_MAKE_SET\n");
		if (TRUE == VarBuild.Bool_dossier_lib_statique) {
			fprintf( fp, "# AM_PROG_LIBTOOL\n");
			fprintf( fp, "AC_PROG_RANLIB\n");
			fprintf( fp, "AM_PROG_CC_C_O\n");
		
			fprintf( fp, "\nAC_DEFINE(ENABLE_STATIC_LIBRARY,1,[Define for enable static library])\n");
		}

		fprintf( fp, "\n# Enable silent rules if supported\n");
		fprintf( fp, "m4_ifdef([AM_SILENT_RULES], [AM_SILENT_RULES([yes])])\n");

		fprintf( fp, "\n# Set PREFIX: ./configure  OR ./configure --prefix=/usr\n");
		fprintf( fp, "AC_SUBST(INSTALL_PREFIX)\n");
		fprintf( fp, "AC_PREFIX_DEFAULT(/usr/local)\n");
		fprintf( fp, "if [[ $prefix = \"NONE\" ]] ; then\n");
		fprintf( fp, "\tAC_DEFINE(INSTALL_PREFIX, \"/usr/local\",\n");
		fprintf( fp, "\t\t[define as prefix where %s is installed])\n", VarBuild.NameProject);
		fprintf( fp, "else\n");
		fprintf( fp, "\tAC_DEFINE_UNQUOTED(INSTALL_PREFIX, \"$prefix\")\n");
		fprintf( fp, "fi\n");
	
		if (TRUE == VarBuild.Bool_dossier_glade) {
			fprintf( fp, "\n# Set used name package glade: *.glade\n");
			fprintf( fp, "AC_DEFINE(PACKAGE_NAME_GLADE, \"%s.glade\", [define as package name of glade])\n", VarBuild.NameProject);
		}
	
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "\n# nls support\n");
			fprintf( fp, "AC_MSG_CHECKING(for nls mode support)\n");
			fprintf( fp, "BASEBUILD_LANG=\"en en_GB fr de it\"\n");
			fprintf( fp, "AC_ARG_ENABLE(nls, , [\n");
			fprintf( fp, "if test \"$enableval\" = \"yes\"; then\n");
			fprintf( fp, "\tALL_LINGUAS=$BASEBUILD_LANG\n");
			fprintf( fp, "\tAC_MSG_RESULT(yes)\n");
			fprintf( fp, "\tAM_GNU_GETTEXT([external])\n");
			fprintf( fp, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
			fprintf( fp, "else\n");
			fprintf( fp, "\tAC_MSG_RESULT(no)\n");
			fprintf( fp, "\tALL_LINGUAS=""\n");
			fprintf( fp, "\tUSE_NLS=\"no\"\n");
			fprintf( fp, "fi\n");
			fprintf( fp, "], [\n");
			fprintf( fp, "\tALL_LINGUAS=$BASEBUILD_LANG\n");
			fprintf( fp, "\tAC_MSG_RESULT(yes)\n");
			fprintf( fp, "\tAM_GNU_GETTEXT([external])\n");
			fprintf( fp, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
			fprintf( fp, "])\n\n");
			fprintf( fp, "GETTEXT_PACKAGE=[$PACKAGE]\n");
			fprintf( fp, "AC_SUBST(GETTEXT_PACKAGE)\n");
			fprintf( fp, "AC_DEFINE_UNQUOTED([GETTEXT_PACKAGE],[\"$GETTEXT_PACKAGE\"],[gettext domain])\n");
		}
	
		fprintf( fp, "\n# Checks for libraries.\n");
		if (TRUE == VarBuild.Bool_dossier_lib_statique) {
			fprintf( fp, "AC_CHECK_LIB([%s], [libH_print_mess])\n", VarBuild.NameLib);
		}
		
		// 
		// IF USE math.h MODULE:
		// 
		// # 
		// # LDFLAGS="-lm$LDFLAGS"
		// # Check for complex math functions support: -lm
		// #
		// AC_CHECK_LIB([m],[csin],,,)
		
		fprintf( fp, "\n# Checks for header files.\n");
		fprintf( fp, "AC_HEADER_STDC\n");
		fprintf( fp, "AC_CHECK_HEADERS([libintl.h stdlib.h string.h unistd.h])\n");
	
		fprintf( fp, "\n# Checks for typedefs, structures, and compiler characteristics.\n");

		fprintf( fp, "\n# Checks for library functions.\n");
		fprintf( fp, "AC_FUNC_STAT\n");
		fprintf( fp, "AC_CHECK_FUNCS([setlocale strchr strrchr])\n");
	
		{
			GString		*GstrSrc = g_string_new (NULL);
	
			g_string_append_printf( GstrSrc, "\n#\n" );
			g_string_append_printf( GstrSrc, "# debug and ansi support\n" );
			g_string_append_printf( GstrSrc, "#\n" );
			g_string_append_printf( GstrSrc, "AC_ARG_ENABLE(debug_pg, AC_HELP_STRING([--disable-debug-pg], [Enable debug mode (default=disable)]),,enable_debug_pg=no)\n" );
			g_string_append_printf( GstrSrc, "AC_ARG_ENABLE(debug, AC_HELP_STRING([--disable-debug], [Disable debug mode (default=disable)]),,enable_debug=no)\n" );
			g_string_append_printf( GstrSrc, "AC_ARG_ENABLE(ansi,  AC_HELP_STRING([--disable-ansi],  [Enable ansi (default=enabled)]),,enable_ansi=no)\n" );
			g_string_append_printf( GstrSrc, "\n" );
			g_string_append_printf( GstrSrc, "AC_MSG_CHECKING(for debug mode request)\n" );
			g_string_append_printf( GstrSrc, "if test \"$enable_debug\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, " 	AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "	AC_DEFINE(DEBUG,1,[Define for debug support])\n" );
			g_string_append_printf( GstrSrc, "	AC_MSG_CHECKING(With ansi compilate)\n" );
			g_string_append_printf( GstrSrc, "	if test \"$enable_ansi\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_CHECKING(With enable_debug_pg)\n" );
			g_string_append_printf( GstrSrc, "		if test \"$enable_debug_pg\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n" );
			
			if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
			} else {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -g -O2 -Wall -ansi \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -g -O2 -Wall -ansi\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-g -O2 -Wall -ansi \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-g -O2 -Wall -ansi\"\n" );
			}
			
			
			
			g_string_append_printf( GstrSrc, "		fi\n" );
			g_string_append_printf( GstrSrc, "	else\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_RESULT(no)\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_CHECKING(With enable_debug_pg)\n" );
			g_string_append_printf( GstrSrc, "		if test \"$enable_debug_pg\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n" );
			if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -g -O2 -Wall -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-g -O2 -Wall -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
			} else {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -g -O2 -Wall \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -g -O2 -Wall  \"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-g -O2 -Wall \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-g -O2 -Wall  \"\n" );
			}
			g_string_append_printf( GstrSrc, "		fi\n" );
			g_string_append_printf( GstrSrc, "	fi\n" );
			g_string_append_printf( GstrSrc, "else\n" );
			g_string_append_printf( GstrSrc, " 	AC_MSG_RESULT(no)\n" );
			g_string_append_printf( GstrSrc, "	AC_MSG_CHECKING(With ansi compilate)\n" );
			g_string_append_printf( GstrSrc, " 	if test \"$enable_ansi\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, " 		AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_CHECKING(With enable_debug_pg)\n" );
			g_string_append_printf( GstrSrc, "		if test \"$enable_debug_pg\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n" );
			if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -Wall -ansi -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-Wall -ansi -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
			} else {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -Wall -ansi \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -Wall -ansi\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-Wall -ansi \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-Wall -ansi\"\n" );
			}
			g_string_append_printf( GstrSrc, "		fi\n" );
			g_string_append_printf( GstrSrc, "	else\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_RESULT(no)\n" );
			g_string_append_printf( GstrSrc, "		AC_MSG_CHECKING(With enable_debug_pg)\n" );
			g_string_append_printf( GstrSrc, "		if test \"$enable_debug_pg\" = \"yes\"; then\n" );
			g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(yes)\n" );
			g_string_append_printf( GstrSrc, "			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n" );
			if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -Wall -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-Wall -D_REENTRANT -DLinux\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-Wall -O3 -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n" );
			} else {
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=yes\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-pg -Wall \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-pg -Wall  \"\n" );
				g_string_append_printf( GstrSrc, "		else\n" );
				g_string_append_printf( GstrSrc, "			AC_MSG_RESULT(no)\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=no\"\n" );
				g_string_append_printf( GstrSrc, "			echo \"*** CFLAGS=-Wall \"\n" );
				g_string_append_printf( GstrSrc, "			echo \"***\"\n" );
				g_string_append_printf( GstrSrc, "			CFLAGS=\"-Wall -O3  \"\n" );
			}
			g_string_append_printf( GstrSrc, "		fi\n" );
			g_string_append_printf( GstrSrc, "	fi\n" );
			g_string_append_printf( GstrSrc, "fi\n" );
			g_string_append_printf( GstrSrc, "\n" );
		
			fprintf( fp, "%s", GstrSrc->str );

			g_string_free( GstrSrc, TRUE );
		}

		if( TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_lib_glib ) {
			fprintf( fp, "\n#\n#%s%s support\n#\n",
						VarBuild.Bool_lib_gtk ? " gtk+-2.0" : "",
						VarBuild.Bool_lib_glib ? " glib-2.0" : ""
						);
			fprintf( fp, "pkg_modules=\"%s%s\"\n",
						VarBuild.Bool_lib_gtk ? "gtk+-2.0 " : "",
						VarBuild.Bool_lib_glib ? "glib-2.0 " : ""
						);
		
			fprintf( fp, "PKG_CHECK_MODULES(PACKAGE, [$pkg_modules])\n");
			fprintf( fp, "AC_SUBST(PACKAGE_CFLAGS)\n");
			fprintf( fp, "AC_SUBST(PACKAGE_LIBS)\n");
		}

		{
			GString		*GstrSrc = NULL;
			GList		*List = NULL;
			VAR_BUILD_SRC	*VarBuildSrc = NULL;
			gchar		*StrLib = g_strdup_printf ("%s/Makefile\n", VarBuild.NameLib);
		
			GstrSrc = g_string_new (NULL);
			List = g_list_first (VarBuild.ListPathSrc);
			while (List) {
				if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
					g_string_append_printf (GstrSrc, "%s/Makefile\n", VarBuildSrc->Name);
				}
				List = g_list_next (List);
			}
		
			fprintf( fp, "\nAC_CONFIG_FILES([\n%s%sMakefile\n%s%s%s%s%s%s])\n",
								VarBuild.Bool_dossier_po ? "po/Makefile.in\n" : "",
								VarBuild.Bool_dossier_lib_statique ? StrLib : "",
								GstrSrc->str,
								VarBuild.Bool_dossier_manpage ? "man/Makefile\n" : "",
								VarBuild.Bool_dossier_pixmaps ? "pixmaps/Makefile\n" : "",
								VarBuild.Bool_dossier_menu ? "menu/Makefile\n" : "",
								VarBuild.Bool_dossier_mime ? "mime/Makefile\n" : "",
								VarBuild.Bool_dossier_glade ? "glade/Makefile\n" : ""
								);
			g_free (StrLib);
			StrLib = NULL;
			g_string_free (GstrSrc, TRUE);
		}
	
	
		fprintf( fp, "\nAC_OUTPUT\n");

		fprintf( fp, "\necho \"\n");
		fprintf( fp, "=================================================================\n");
		fprintf( fp, "  configure.in product with BaseBuild: \n");
		fprintf( fp, "      http://www.xcfa.tuxfamily.org/\n");
		fprintf( fp, "=================================================================\n");
		fprintf( fp, "  Configuration for $PACKAGE $VERSION :\n");
		fprintf( fp, "=================================================================\n\n");
		fprintf( fp, "  Host System Type ................ : $host\n");
		fprintf( fp, "  HosName ......................... : `hostname`\n");
		fprintf( fp, "  Compiler ........................ : $CC $CPPFLAGS\n");
		fprintf( fp, "  Linker .......................... : $CC $LDFLAGS");
		if (TRUE == VarBuild.Bool_lib_gtk) {
			fprintf( fp, " $LIBS\n");
		}
		else {
			fprintf( fp, "\n");
		}
		if (TRUE == VarBuild.Bool_dossier_po) {
			fprintf( fp, "  NLS/gettext ..................... : $USE_NLS\n");
			fprintf( fp, "  ALL_LINGUAS ..................... : $ALL_LINGUAS\n");
		}
		if( TRUE == VarBuild.Bool_lib_gtk ) {
			fprintf( fp, "  GTK+ version .................... : `pkg-config --modversion gtk+-2.0`\n");
		}
		if( TRUE == VarBuild.Bool_lib_glib ) {
			fprintf( fp, "  GLIB version .................... : `pkg-config --modversion glib-2.0`\n");
		}
		fprintf( fp, "  Debug mode g .................... : $enable_debug\n");
		fprintf( fp, "  Debug mode pg ................... : $enable_debug_pg\n");
		fprintf( fp, "  WITH ANSI COMPILATE ............. : $enable_ansi\n");
		fprintf( fp, "  CFLAGS .......................... : $CFLAGS\n");
		fprintf( fp, "  INSTALL ......................... : $prefix/bin/%s\n\n", VarBuild.NameProject);
		fprintf( fp, "  Options parameters:\n");
		fprintf( fp, "  -------------------\n");
		fprintf( fp, "  by default:\n");
		fprintf( fp, "  	--disable-debug                             No debug support\n");
		fprintf( fp, "  	--disable-debug-pg                          No debug support with gprof\n");
		fprintf( fp, "  	--disable-ansi                              No define ansi for probleme compilate\n");
		fprintf( fp, "  Options is:\n");
		fprintf( fp, "  	--enable-debug      #define DEBUG 1         Define for debug: -g\n");
		fprintf( fp, "  	--enable-debug-pg   #define DEBUG_PG 1      Define for debug support with gprof: -pg\n");
		fprintf( fp, "  	--enable-ansi       #define ENABLE_ANSI 1   Define With ansi compilate\n\n");
		fprintf( fp, "  Now type 'make' to build $PACKAGE $VERSION,\n");
		fprintf( fp, "  and then type (under root) 'make install' for installation.\n");
		fprintf( fp, "\"\n");
		
		fclose( fp );
	}
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}
}
// 
// TMP/GETTEXTIZE.SH
// 
void BuildWrite_GETTEXTIZE_file( void )
{
	FILE		*fp = NULL;
	gchar		*PathNameFile = g_strdup( "/tmp/set-gettextize.sh" );
	
	if( NULL != ( fp = fopen( PathNameFile, "w" ))) {
		
		fprintf( fp, "#!/bin/sh\n");
		fprintf( fp, "PROGRAM=gettextize\n");
		fprintf( fp, "sed 's:read .*< /dev/tty::' `which $PROGRAM` > /tmp/my-gettextize.sh\n");
		fprintf( fp, "chmod +x /tmp/my-gettextize.sh\n");
		fprintf( fp, "exit 0\n");
		fflush( fp );
		fclose( fp );
	}
	
	if( NULL != PathNameFile ) {
		g_free( PathNameFile );
		PathNameFile = NULL;
	}

	conv_with_args( "chmod", "+x", "/tmp/set-gettextize.sh", NULL);
	conv_with_args( "/tmp/set-gettextize.sh", NULL );
}
// 
// PO/fr.po
// 
void BuildWrite_PO_file( gchar *PathNamaneFile_PO )
{
	FILE	*fp = NULL;
	gchar	*PathName = NULL;
	gchar	*NamePo[] = {"en.po", "en_GB.po", "fr.po", "de.po", "it.po" };
	gchar	*Language[] = {"English", "English", "French", "German", "Italy" };
	gint	Cpt;
	
	for (Cpt = 0; Cpt < 5; Cpt ++) {
		
		PathName = g_strdup_printf ("%s/%s", PathNamaneFile_PO, NamePo [ Cpt ]);
		if (NULL != (fp = fopen (PathName, "w"))) {
		
			fprintf( fp, "# SOME DESCRIPTIVE TITLE.\n");
			fprintf( fp, "# Copyright (C) YEAR Free Software Foundation, Inc.\n");
			fprintf( fp, "# This file is distributed under the same license as the PACKAGE package.\n");
			fprintf( fp, "# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.\n");
			fprintf( fp, "#\n");
			// fprintf( fp, "#, fuzzy\n");
			fprintf( fp, "msgid \"\"\n");
			fprintf( fp, "msgstr \"\"\n");
			fprintf( fp, "\"Project-Id-Version: %s %s\\n\"\n", VarBuild.NameProject, VarBuild.VersionProject);
			fprintf( fp, "\"Report-Msgid-Bugs-To: Emailr@Adress.Ext\\n\"\n");
			fprintf( fp, "\"POT-Creation-Date: 2010-05-06 16:59+0200\\n\"\n");
			fprintf( fp, "\"PO-Revision-Date: 2010-05-06 16:59+0200\\n\"\n");
			fprintf( fp, "\"Last-Translator: MyName <Emailr@Adress.Ext>\\n\"\n");
			fprintf( fp, "\"Language-Team: %s\\n\"\n", Language [ Cpt ]);
			fprintf( fp, "\"MIME-Version: 1.0\\n\"\n");
			fprintf( fp, "\"Content-Type: text/plain; charset=UTF-8\\n\"\n");
			fprintf( fp, "\"Content-Transfer-Encoding: 8bit\\n\"\n");
		
			fflush( fp );
			fclose (fp);
		}
		
		g_free (PathName);
		PathName = NULL;
	}
}
















