 /*
 * file      : conv.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <pthread.h>
#include <sys/types.h>
#include <signal.h>
#include <sys/wait.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>	// PROCESSUS NON-BLOQUANT

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_basebuild/libbasebuild.h"
#endif

#include "global.h"
#include "conv.h"


/*
*---------------------------------------------------------------------------
* VARIABLES
*---------------------------------------------------------------------------
*/

#define CONV_MAX_CARS 1024

CONV conv;

/*
*---------------------------------------------------------------------------
* SIGNAL ET EXTRACTION
*---------------------------------------------------------------------------
*/
void conv_sigchld( gint signum )
{
        gint	status;
        
        wait( &status );
	/* PRINT_FUNC_LF(); */
        /* if there are still children waiting
        *  re-install the signal handler
	*/
	conv.signal_numchildren --;
        if (conv.signal_numchildren > 0)
        {
                /* re-install the signal handler */
                signal (SIGCHLD, conv_sigchld);
        }
}
int conv_call_exec( gchar **args, pid_t *p, gint p_output )
{
	gchar	**ptr = (gchar **)args;
	gint	status;

	conv.signal_numchildren = 0;
	if (pipe (conv.tube) != 0)
	{
		fprintf (stderr, "error: pipe\n");
		exit (1);
	}
	if ((*p = fork()) == 0)
	{
		dup2 (conv.tube [1 ], p_output);
		close (conv.tube [ 1 ]);
		execvp ((gchar *)*(ptr+0), ptr);
		fprintf (stderr, "error: exec");
		exit (2);
	}
	conv.signal_numchildren ++;
	signal (SIGCHLD, conv_sigchld);
	close(conv.tube [ 1 ]);
	
	// LE FICHIER EST OUVERT EN MODE « NON-BLOQUANT »
	status = fcntl( conv.tube [ 0 ], F_GETFL );
	status = fcntl( conv.tube [ 0 ], F_SETFL, status | O_NONBLOCK );
	
	return (conv.tube [ 0 ]);
}
// RESET STRUCTURE CONV
//
void conv_reset_struct( void )
{
	gint	i;
	
	// PRINT_FUNC_LF();
	
	conv.code_fork          = -1;
	conv.signal_numchildren = 0;
	for (i = 0; i < MAX_ARG_CONV; i++) {
		conv.ArgConv [ i ] = NULL;
	}
}
// 
// 
gint conv_remove( void )
{
	gint	pos = 0;
	
	for (pos = 0; conv.ArgConv [ pos ] != NULL; pos ++) {
		g_free (conv.ArgConv [ pos ]);
		conv.ArgConv [ pos ] = NULL;
	}
	return (0);
}
// 
// 
gint conv_set_nice( void )
{
	gint	pos = conv_remove ();
	
	conv.ArgConv [ pos++ ] = g_strdup( "nice" );
	conv.ArgConv [ pos++ ] = g_strdup( "-n" );
	conv.ArgConv [ pos++ ] = g_strdup( "0" );
	
	// RETOURNE LA PROCHANE POSITION DE pos
	return (3);
}
// LSDVD
// 
void conv_exec( gchar **args )
{
	gint       fd;
	gint       size;
	gint       pos = 0;
	gchar      buf [ CONV_MAX_CARS + 10 ];

	fd = conv_call_exec (args, &conv.code_fork, STDERR_FILENO);

	do
	{
		pos = -1;
		do
		{
			pos++;
			if (pos >= CONV_MAX_CARS) {
				PRINT_FUNC_LF();
				if( TRUE == OptionsCommandLine.BoolVerboseMode )
					g_print ("pos(%d) >= CONV_MAX_CARS(%d)\n", pos, CONV_MAX_CARS);
				pos --;
			}
			size = read(fd, &buf[pos], 1);
			
		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
		buf[pos++] = '\n';
		buf[pos] = '\0';
		
		while (gtk_events_pending()) gtk_main_iteration();

	} while (size != 0);

	close(fd);
	conv.code_fork = -1;
}
// 
// 
void conv_with_args( gchar *p_text, ... )
{
	gint	pos;
	va_list	VaList;
	gchar	*Ptr = NULL;
		
	conv_reset_struct();
	
	pos = conv_set_nice ();
	
	conv.ArgConv [ pos++ ] = g_strdup( p_text );
	va_start( VaList, p_text );
	while( NULL != ( Ptr = va_arg( VaList, gchar * ))) {
		conv.ArgConv [ pos++ ] = g_strdup( Ptr );
	}
	va_end( VaList );
	conv.ArgConv [ pos++ ] = NULL;
	
	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
		g_print ("\n!-----------------------------------------------------------!\n! ");
		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
			g_print ("%s ", conv.ArgConv[ pos ]);
		}
		g_print ("\n!-----------------------------------------------------------!\n");
		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
			g_print ("! ArgConv[ %02d ] = %s\n", pos, conv.ArgConv[ pos ]);
		}
		g_print ("!-----------------------------------------------------------!\n\n");
	}
	
	conv_exec( conv.ArgConv );
	
	conv_remove ();
}







